@@ -9,12 +9,39 @@
 #include <glib.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
-#include <gnome.h>
 #include <panel-applet.h>
+#include <panel-applet-gconf.h>
 
 #include "global.h"
 
-static GList *object_list = NULL;
+
+/*
+  Shifts data right
+
+  data[i+1] = data[i]
+
+  data[i] are int*, so we just move the pointer, not the data.
+  But moving data loses data[n-1], so we save data[n-1] and reuse
+  it as new data[0]. In fact, we rotate data[].
+
+*/
+
+static void
+shift_right(LoadGraph *g)
+{
+	unsigned i;
+	int* last_data;
+
+	/* data[g->draw_width - 1] becomes data[0] */
+	last_data = g->data[g->draw_width - 1];
+
+	/* data[i+1] = data[i] */
+	for(i = g->draw_width - 1; i != 0; --i)
+		g->data[i] = g->data[i-1];
+
+	g->data[0] = last_data;
+}
+
 
 /* Redraws the backing pixmap for the load graph and updates the window */
 static void
@@ -82,31 +109,22 @@ load_graph_draw (LoadGraph *g)
 		       0, 0,
 		       g->draw_width,
 		       g->draw_height);
-	
-    for (i = 0; i < g->draw_width; i++)
-		memcpy (g->odata [i], g->data [i], g->data_size);
-	
-	return;
 }
 
 /* Updates the load graph when the timeout expires */
 static gboolean
 load_graph_update (LoadGraph *g)
 {
-    guint i, j;
-
     if (g->data == NULL)
 	return TRUE;
-    
+
+    shift_right(g);
+
     if (g->tooltip_update)
 	multiload_applet_tooltip_update(g);
     else		
 	g->get_data (g->draw_height, g->data [0], g);
 
-    for (i=0; i < g->draw_width-1; i++)
-		for (j=0; j < g->n; j++)
-		    g->data [i+1][j] = g->odata [i][j];
-
     load_graph_draw (g);
     return TRUE;
 }
@@ -114,7 +132,7 @@ load_graph_update (LoadGraph *g)
 void
 load_graph_unalloc (LoadGraph *g)
 {
-    int i;
+    guint i;
 	
     if (!g->allocated)
 		return;
@@ -122,15 +140,13 @@ load_graph_unalloc (LoadGraph *g)
     for (i = 0; i < g->draw_width; i++)
     {
 		g_free (g->data [i]);
-		g_free (g->odata [i]);
     }
 
     g_free (g->data);
-    g_free (g->odata);
     g_free (g->pos);
 
     g->pos = NULL;
-    g->data = g->odata = NULL;
+    g->data = NULL;
     
     g->size = panel_applet_gconf_get_int(g->applet, "size", NULL);
     g->size = MAX (g->size, 10);
@@ -151,26 +167,24 @@ load_graph_unalloc (LoadGraph *g)
 static void
 load_graph_alloc (LoadGraph *g)
 {
-    int i;
+    guint i;
 
     if (g->allocated)
 		return;
 
-    g->data = g_new0 (guint *, g->draw_width);
-    g->odata = g_new0 (guint *, g->draw_width);
+    g->data = g_new0 (gint *, g->draw_width);
     g->pos = g_new0 (guint, g->draw_width);
 
     g->data_size = sizeof (guint) * g->n;
 
     for (i = 0; i < g->draw_width; i++) {
 		g->data [i] = g_malloc0 (g->data_size);
-		g->odata [i] = g_malloc0 (g->data_size);
     }
 
     g->allocated = TRUE;
 }
 
-gint
+static gint
 load_graph_configure (GtkWidget *widget, GdkEventConfigure *event,
 		      gpointer data_ptr)
 {
@@ -235,11 +249,9 @@ load_graph_destroy (GtkWidget *widget, gpointer data_ptr)
     }
 
     gtk_widget_destroy(widget);
-    object_list = g_list_remove (object_list, g);
-    return;
 }
 
-void
+static void
 load_graph_load_config (LoadGraph *g)
 {
 	
@@ -347,10 +359,8 @@ load_graph_new (PanelApplet *applet, guint n, gchar *label,
 	
     gtk_box_pack_start (GTK_BOX (g->box), g->disp, TRUE, TRUE, 0);    
     gtk_widget_show_all(g->box);
-    object_list = g_list_append (object_list, g);
     
     return g;
-    label = NULL;
 }
 
 void
