@@ -24,6 +24,7 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gconf/gconf-client.h>
 #include <libgnome/gnome-desktop-item.h> 
+#include <libgnomeui/gnome-help.h>
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
 
@@ -34,7 +35,7 @@ about_cb (BonoboUIComponent *uic,
 	  MultiloadApplet   *ma,
 	  const char        *name)
 {
-    static const gchar *authors[] =
+    const gchar * const authors[] =
     {
 		"Martin Baulig <martin@home-of-linux.org>",
 		"Todd Kulesza <fflewddur@dropline.net>",
@@ -43,7 +44,7 @@ about_cb (BonoboUIComponent *uic,
 		NULL
     };
 
-    const gchar *documenters[] =
+    const gchar * const documenters[] =
     {
 		"Chee Bin HOH <cbhoh@gnome.org>",
 		"Sun GNOME Documentation Team <gdocteam@sun.com>",
@@ -315,7 +316,7 @@ multiload_key_press_event_cb (GtkWidget *widget, GdkEventKey *event, MultiloadAp
 void
 multiload_applet_tooltip_update(LoadGraph *g)
 {
-	gint i, total_used, percent, mem_used, used_percent;
+	guint i, total_used, percent, mem_used, used_percent;
 	gchar *tooltip_text, *name;
 
 	g_return_if_fail(g);
@@ -337,7 +338,7 @@ multiload_applet_tooltip_update(LoadGraph *g)
 	else if (!strncmp (g->name, "diskload", strlen("diskload")))
 		name = g_strdup(_("Disk"));
 	else
-		name = g_strdup(_("Resource"));
+		g_assert_not_reached();
 	
 	/* fill data[0] with the current load */
 	g->get_data (g->draw_height, g->data[0], g);
@@ -353,11 +354,29 @@ multiload_applet_tooltip_update(LoadGraph *g)
 		used_percent = 100 * (gdouble)mem_used / (gdouble)g->draw_height;
 		used_percent = CLAMP (used_percent, 0, 100);
 		
-		tooltip_text = g_strdup_printf(_("%s:\n%d%% in use of which\n%d%% is cache"), name, percent,
-				percent - used_percent);
-	} else
-		tooltip_text = g_strdup_printf(_("%s:\n%d%% in use"), name, percent);
-	
+		/* xgettext: use and cache are > 1 most of the time,
+		   please assume that they always are.
+		 */
+		tooltip_text = g_strdup_printf(_("%s:\n"
+						 "%u%% in use of which\n"
+						 "%u%% is cache"),
+					       name,
+					       percent,
+					       percent - used_percent);
+	} else {
+		const char *msg;
+
+		msg = ngettext("%s:\n"
+			       "%u%% in use",
+			       "%s:\n"
+			       "%u%% in use",
+			       percent);
+
+		tooltip_text = g_strdup_printf(msg,
+					       name,
+					       percent);
+	}
+
 	gtk_tooltips_set_tip(g->tooltips, g->disp, tooltip_text, tooltip_text);
 		
 	g_free(tooltip_text);
